@@ -8,7 +8,7 @@ import {
     DeviceTupleService,
     ServerInfoTuple,
 } from "@peek/peek_core_device/_private";
-import { DeviceTypeEnum } from "@peek/peek_core_device/_private/hardware-info/hardware-info.abstract";
+import { DeviceTypeEnum } from "@peek/peek_core_device/_private/hardware-info/hardware-info";
 import { Capacitor } from "@capacitor/core";
 
 @Component({
@@ -17,8 +17,9 @@ import { Capacitor } from "@capacitor/core";
 })
 export class ConnectComponent extends NgLifeCycleEvents implements OnInit {
     server: ServerInfoTuple = new ServerInfoTuple();
-    httpPortStr: string = "8000";
-    websocketPortStr: string = "8001";
+    httpPortStr: string = ServerInfoTuple.DEFAULT_HTTP_PORT.toString();
+    websocketPortStr: string =
+        ServerInfoTuple.DEFAULT_WEBSOCKET_PORT.toString();
     deviceType: DeviceTypeEnum;
     isWeb: boolean;
     platform: string;
